Learn R Programming

mhde (version 1.0-1)

mhde.cn: Utility function for retrieving $Cn$ value for any sample size

Description

This function evaluates the $Cn$ bandwidth value for the Epanechnikov kernel based on the sample size.

Usage

mhde.cn(Nsize)

Arguments

Nsize
Number of values in the sample data set

Value

The Epanechnikov kernel bandwidth parameter for the sample size.