mhde.test(DataVec, NGauss = 100, MaxIter = 25, InitLocation, InitScale,
EpsLoc = 1e-04, EpsSca = 1e-04, Silent = FALSE, Small = FALSE)NGauss. A default value of 100 is used. A minimum of 25 is enforced.MaxIter. A default of 25 is used. A minimum of 1 is enforced.InitLocation. The data median is the default value.InitScale. The data median absolute deviation is the default value.EpsLoc. EpsLoc should be set to give approximately 5 digits of accuracy in the location eEpsSca. EpsSca should be set to give approximately 5 digits of accuracy in the scale estimatSilent writes several results to the R console. Use Silent=TRUE to eliminate the output.Small returns a list of 11 objects. Use Small=TRUE to return a shorter list containing only the Hellinger distance and the p-value.## example with a normal data set
mhde.test(rnorm(20,0.0,1.0),Small=TRUE)
## example with a uniform data set including example plot
MyList <- mhde.test(runif(25,min=2,max=4))
mhde.plot(MyList)Run the code above in your browser using DataLab